/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<basictheme_p.h>)
#  include <basictheme_p.h>
#endif
#if __has_include(<colorutils.h>)
#  include <colorutils.h>
#endif
#if __has_include(<inputmethod.h>)
#  include <inputmethod.h>
#endif
#if __has_include(<platformtheme.h>)
#  include <platformtheme.h>
#endif
#if __has_include(<settings.h>)
#  include <settings.h>
#endif
#if __has_include(<stylehints.h>)
#  include <stylehints.h>
#endif
#if __has_include(<units.h>)
#  include <units.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami_platform()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ColorUtils>("org.kde.kirigami.platform", 2);
    qmlRegisterEnum<ColorUtils::Brightness>("ColorUtils::Brightness");
    qmlRegisterTypesAndRevisions<Kirigami::Platform::BasicThemeDefinition>("org.kde.kirigami.platform", 2);
    qmlRegisterTypesAndRevisions<Kirigami::Platform::IconSizes>("org.kde.kirigami.platform", 2);
    qmlRegisterTypesAndRevisions<Kirigami::Platform::InputMethod>("org.kde.kirigami.platform", 2);
    qmlRegisterTypesAndRevisions<Kirigami::Platform::PlatformTheme>("org.kde.kirigami.platform", 2);
    qmlRegisterEnum<Kirigami::Platform::PlatformTheme::ColorSet>("Kirigami::Platform::PlatformTheme::ColorSet");
    qmlRegisterEnum<Kirigami::Platform::PlatformTheme::ColorGroup>("Kirigami::Platform::PlatformTheme::ColorGroup");
    qmlRegisterTypesAndRevisions<Kirigami::Platform::Settings>("org.kde.kirigami.platform", 2);
    qmlRegisterTypesAndRevisions<Kirigami::Platform::StyleHints>("org.kde.kirigami.platform", 2);
    qmlRegisterTypesAndRevisions<Kirigami::Platform::Units>("org.kde.kirigami.platform", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami.platform", 2, 0);
}

static const QQmlModuleRegistration orgkdekirigamiplatformRegistration("org.kde.kirigami.platform", qml_register_types_org_kde_kirigami_platform);
