/****************************************************************************
** Meta object code from reading C++ file 'mnemonicattached.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.25.0/src/primitives/mnemonicattached.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mnemonicattached.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16MnemonicAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto MnemonicAttached::qt_create_metaobjectdata<qt_meta_tag_ZN16MnemonicAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MnemonicAttached",
        "QML.Element",
        "MnemonicData",
        "QML.Attached",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create objects of type MnemonicData, use it as an attached "
        "property",
        "labelChanged",
        "",
        "enabledChanged",
        "sequenceChanged",
        "richTextLabelChanged",
        "mnemonicLabelChanged",
        "plainTextLabelChanged",
        "controlTypeChanged",
        "activeChanged",
        "label",
        "richTextLabel",
        "mnemonicLabel",
        "plainTextLabel",
        "enabled",
        "controlType",
        "MnemonicAttached::ControlType",
        "sequence",
        "QKeySequence",
        "active",
        "ControlType",
        "ActionElement",
        "DialogButton",
        "MenuItem",
        "FormLabel",
        "SecondaryControl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void()>(8, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(10, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sequenceChanged'
        QtMocHelpers::SignalData<void()>(11, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'richTextLabelChanged'
        QtMocHelpers::SignalData<void()>(12, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mnemonicLabelChanged'
        QtMocHelpers::SignalData<void()>(13, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plainTextLabelChanged'
        QtMocHelpers::SignalData<void()>(14, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controlTypeChanged'
        QtMocHelpers::SignalData<void()>(15, 9, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(16, 9, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'label'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'richTextLabel'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'mnemonicLabel'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'plainTextLabel'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'controlType'
        QtMocHelpers::PropertyData<MnemonicAttached::ControlType>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 6),
        // property 'sequence'
        QtMocHelpers::PropertyData<QKeySequence>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ControlType'
        QtMocHelpers::EnumData<enum ControlType>(27, 27, QMC::EnumFlags{}).add({
            {   28, ControlType::ActionElement },
            {   29, ControlType::DialogButton },
            {   30, ControlType::MenuItem },
            {   31, ControlType::FormLabel },
            {   32, ControlType::SecondaryControl },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<MnemonicAttached, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MnemonicAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MnemonicAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MnemonicAttachedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16MnemonicAttachedE_t>.metaTypes,
    nullptr
} };

void MnemonicAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MnemonicAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->labelChanged(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->sequenceChanged(); break;
        case 3: _t->richTextLabelChanged(); break;
        case 4: _t->mnemonicLabelChanged(); break;
        case 5: _t->plainTextLabelChanged(); break;
        case 6: _t->controlTypeChanged(); break;
        case 7: _t->activeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::labelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::sequenceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::richTextLabelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::mnemonicLabelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::plainTextLabelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::controlTypeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MnemonicAttached::*)()>(_a, &MnemonicAttached::activeChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->richTextLabel(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->mnemonicLabel(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->plainTextLabel(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 5: *reinterpret_cast<MnemonicAttached::ControlType*>(_v) = _t->controlType(); break;
        case 6: *reinterpret_cast<QKeySequence*>(_v) = _t->sequence(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setControlType(*reinterpret_cast<MnemonicAttached::ControlType*>(_v)); break;
        case 7: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MnemonicAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MnemonicAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MnemonicAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MnemonicAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MnemonicAttached::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MnemonicAttached::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MnemonicAttached::sequenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MnemonicAttached::richTextLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MnemonicAttached::mnemonicLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MnemonicAttached::plainTextLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MnemonicAttached::controlTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MnemonicAttached::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
