/****************************************************************************
** Meta object code from reading C++ file 'toolbarlayout.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.25.0/src/layouts/toolbarlayout.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'toolbarlayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ToolBarLayoutAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto ToolBarLayoutAttached::qt_create_metaobjectdata<qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ToolBarLayoutAttached",
        "action"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'action'
        QtMocHelpers::PropertyData<QObject*>(1, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ToolBarLayoutAttached, qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ToolBarLayoutAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>.metaTypes,
    nullptr
} };

void ToolBarLayoutAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToolBarLayoutAttached *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->action(); break;
        default: break;
        }
    }
}

const QMetaObject *ToolBarLayoutAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolBarLayoutAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ToolBarLayoutAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ToolBarLayoutAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13ToolBarLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto ToolBarLayout::qt_create_metaobjectdata<qt_meta_tag_ZN13ToolBarLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ToolBarLayout",
        "QML.Element",
        "auto",
        "QML.Attached",
        "ToolBarLayoutAttached",
        "actionsChanged",
        "",
        "hiddenActionsChanged",
        "fullDelegateChanged",
        "iconDelegateChanged",
        "separatorDelegateChanged",
        "moreButtonChanged",
        "spacingChanged",
        "alignmentChanged",
        "visibleWidthChanged",
        "minimumWidthChanged",
        "layoutDirectionChanged",
        "heightModeChanged",
        "relayout",
        "actions",
        "QQmlListProperty<QObject>",
        "hiddenActions",
        "QList<QObject*>",
        "fullDelegate",
        "QQmlComponent*",
        "iconDelegate",
        "separatorDelegate",
        "moreButton",
        "spacing",
        "alignment",
        "Qt::Alignment",
        "visibleWidth",
        "minimumWidth",
        "layoutDirection",
        "Qt::LayoutDirection",
        "heightMode",
        "HeightMode",
        "AlwaysCenter",
        "AlwaysFill",
        "ConstrainIfLarger"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hiddenActionsChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullDelegateChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconDelegateChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'separatorDelegateChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moreButtonChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spacingChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumWidthChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutDirectionChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightModeChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'relayout'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'actions'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'hiddenActions'
        QtMocHelpers::PropertyData<QList<QObject*>>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'fullDelegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'iconDelegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'separatorDelegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(26, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'moreButton'
        QtMocHelpers::PropertyData<QQmlComponent*>(27, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'spacing'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'visibleWidth'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'minimumWidth'
        QtMocHelpers::PropertyData<qreal>(32, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'layoutDirection'
        QtMocHelpers::PropertyData<Qt::LayoutDirection>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 10),
        // property 'heightMode'
        QtMocHelpers::PropertyData<enum HeightMode>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HeightMode'
        QtMocHelpers::EnumData<enum HeightMode>(36, 36, QMC::EnumFlags{}).add({
            {   37, HeightMode::AlwaysCenter },
            {   38, HeightMode::AlwaysFill },
            {   39, HeightMode::ConstrainIfLarger },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ToolBarLayout, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ToolBarLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ToolBarLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ToolBarLayoutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ToolBarLayoutE_t>.metaTypes,
    nullptr
} };

void ToolBarLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ToolBarLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionsChanged(); break;
        case 1: _t->hiddenActionsChanged(); break;
        case 2: _t->fullDelegateChanged(); break;
        case 3: _t->iconDelegateChanged(); break;
        case 4: _t->separatorDelegateChanged(); break;
        case 5: _t->moreButtonChanged(); break;
        case 6: _t->spacingChanged(); break;
        case 7: _t->alignmentChanged(); break;
        case 8: _t->visibleWidthChanged(); break;
        case 9: _t->minimumWidthChanged(); break;
        case 10: _t->layoutDirectionChanged(); break;
        case 11: _t->heightModeChanged(); break;
        case 12: _t->relayout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::actionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::hiddenActionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::fullDelegateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::iconDelegateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::separatorDelegateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::moreButtonChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::spacingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::alignmentChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::visibleWidthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::minimumWidthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::layoutDirectionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ToolBarLayout::*)()>(_a, &ToolBarLayout::heightModeChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QObject*> >(); break;
        case 5:
        case 4:
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->actionsProperty(); break;
        case 1: *reinterpret_cast<QList<QObject*>*>(_v) = _t->hiddenActions(); break;
        case 2: *reinterpret_cast<QQmlComponent**>(_v) = _t->fullDelegate(); break;
        case 3: *reinterpret_cast<QQmlComponent**>(_v) = _t->iconDelegate(); break;
        case 4: *reinterpret_cast<QQmlComponent**>(_v) = _t->separatorDelegate(); break;
        case 5: *reinterpret_cast<QQmlComponent**>(_v) = _t->moreButton(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->spacing(); break;
        case 7: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->visibleWidth(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->minimumWidth(); break;
        case 10: *reinterpret_cast<Qt::LayoutDirection*>(_v) = _t->layoutDirection(); break;
        case 11: *reinterpret_cast<enum HeightMode*>(_v) = _t->heightMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setFullDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 3: _t->setIconDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 4: _t->setSeparatorDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 5: _t->setMoreButton(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 6: _t->setSpacing(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 10: _t->setLayoutDirection(*reinterpret_cast<Qt::LayoutDirection*>(_v)); break;
        case 11: _t->setHeightMode(*reinterpret_cast<enum HeightMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ToolBarLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolBarLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ToolBarLayoutE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ToolBarLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ToolBarLayout::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ToolBarLayout::hiddenActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ToolBarLayout::fullDelegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ToolBarLayout::iconDelegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ToolBarLayout::separatorDelegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ToolBarLayout::moreButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ToolBarLayout::spacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ToolBarLayout::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ToolBarLayout::visibleWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ToolBarLayout::minimumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ToolBarLayout::layoutDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ToolBarLayout::heightModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
