/****************************************************************************
** Meta object code from reading C++ file 'icon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.25.0/src/primitives/icon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'icon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4IconE_t {};
} // unnamed namespace

template <> constexpr inline auto Icon::qt_create_metaobjectdata<qt_meta_tag_ZN4IconE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Icon",
        "QML.Element",
        "auto",
        "sourceChanged",
        "",
        "activeChanged",
        "validChanged",
        "selectedChanged",
        "isMaskChanged",
        "colorChanged",
        "fallbackChanged",
        "fallback",
        "placeholderChanged",
        "placeholder",
        "statusChanged",
        "paintedAreaChanged",
        "animatedChanged",
        "roundToIconSizeChanged",
        "source",
        "QVariant",
        "active",
        "valid",
        "selected",
        "isMask",
        "color",
        "QColor",
        "status",
        "Icon::Status",
        "paintedWidth",
        "paintedHeight",
        "animated",
        "roundToIconSize",
        "Status",
        "Null",
        "Ready",
        "Loading",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'validChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isMaskChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'placeholderChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintedAreaChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animatedChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roundToIconSizeChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QVariant>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'fallback'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'placeholder'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'selected'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'isMask'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'status'
        QtMocHelpers::PropertyData<Icon::Status>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 8),
        // property 'paintedWidth'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'paintedHeight'
        QtMocHelpers::PropertyData<qreal>(29, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'animated'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10),
        // property 'roundToIconSize'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 11),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(32, 32, QMC::EnumFlags{}).add({
            {   33, Status::Null },
            {   34, Status::Ready },
            {   35, Status::Loading },
            {   36, Status::Error },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Icon, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Icon::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4IconE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4IconE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4IconE_t>.metaTypes,
    nullptr
} };

void Icon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Icon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->activeChanged(); break;
        case 2: _t->validChanged(); break;
        case 3: _t->selectedChanged(); break;
        case 4: _t->isMaskChanged(); break;
        case 5: _t->colorChanged(); break;
        case 6: _t->fallbackChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->placeholderChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->statusChanged(); break;
        case 9: _t->paintedAreaChanged(); break;
        case 10: _t->animatedChanged(); break;
        case 11: _t->roundToIconSizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::activeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::validChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::selectedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::isMaskChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::colorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)(const QString & )>(_a, &Icon::fallbackChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)(const QString & )>(_a, &Icon::placeholderChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::statusChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::paintedAreaChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::animatedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Icon::*)()>(_a, &Icon::roundToIconSizeChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fallback(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->placeholder(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->valid(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->selected(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isMask(); break;
        case 7: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 8: *reinterpret_cast<Icon::Status*>(_v) = _t->status(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->paintedWidth(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->paintedHeight(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isAnimated(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->roundToIconSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QVariant*>(_v)); break;
        case 1: _t->setFallback(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPlaceholder(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSelected(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setIsMask(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 11: _t->setAnimated(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setRoundToIconSize(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Icon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Icon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4IconE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Icon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Icon::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Icon::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Icon::validChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Icon::selectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Icon::isMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Icon::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Icon::fallbackChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Icon::placeholderChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Icon::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Icon::paintedAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Icon::animatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Icon::roundToIconSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
