/****************************************************************************
** Meta object code from reading C++ file 'pagepool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.25.0/src/controls/pagepool.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pagepool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8PagePoolE_t {};
} // unnamed namespace

template <> constexpr inline auto PagePool::qt_create_metaobjectdata<qt_meta_tag_ZN8PagePoolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PagePool",
        "QML.Element",
        "auto",
        "lastLoadedUrlChanged",
        "",
        "lastLoadedItemChanged",
        "itemsChanged",
        "urlsChanged",
        "cachePagesChanged",
        "loadPage",
        "QQuickItem*",
        "url",
        "QJSValue",
        "callback",
        "loadPageWithProperties",
        "QVariantMap",
        "properties",
        "urlForPage",
        "QUrl",
        "item",
        "pageForUrl",
        "contains",
        "QVariant",
        "page",
        "deletePage",
        "resolvedUrl",
        "file",
        "isLocalUrl",
        "clear",
        "lastLoadedUrl",
        "lastLoadedItem",
        "items",
        "QList<QQuickItem*>",
        "urls",
        "QList<QUrl>",
        "cachePages"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lastLoadedUrlChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastLoadedItemChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cachePagesChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadPage'
        QtMocHelpers::MethodData<QQuickItem *(const QString &, QJSValue)>(9, 4, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'loadPage'
        QtMocHelpers::MethodData<QQuickItem *(const QString &)>(9, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 10, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'loadPageWithProperties'
        QtMocHelpers::MethodData<QQuickItem *(const QString &, const QVariantMap &, QJSValue)>(14, 4, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 15, 16 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'loadPageWithProperties'
        QtMocHelpers::MethodData<QQuickItem *(const QString &, const QVariantMap &)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 10, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'urlForPage'
        QtMocHelpers::MethodData<QUrl(QQuickItem *) const>(17, 4, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 10, 19 },
        }}),
        // Method 'pageForUrl'
        QtMocHelpers::MethodData<QQuickItem *(const QUrl &) const>(20, 4, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 18, 11 },
        }}),
        // Method 'contains'
        QtMocHelpers::MethodData<bool(const QVariant &) const>(21, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'deletePage'
        QtMocHelpers::MethodData<void(const QVariant &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'resolvedUrl'
        QtMocHelpers::MethodData<QUrl(const QString &) const>(25, 4, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'isLocalUrl'
        QtMocHelpers::MethodData<bool(const QUrl &)>(27, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 11 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lastLoadedUrl'
        QtMocHelpers::PropertyData<QUrl>(29, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'lastLoadedItem'
        QtMocHelpers::PropertyData<QQuickItem*>(30, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'items'
        QtMocHelpers::PropertyData<QList<QQuickItem*>>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'urls'
        QtMocHelpers::PropertyData<QList<QUrl>>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 3),
        // property 'cachePages'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PagePool, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PagePool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PagePoolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PagePoolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8PagePoolE_t>.metaTypes,
    nullptr
} };

void PagePool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PagePool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lastLoadedUrlChanged(); break;
        case 1: _t->lastLoadedItemChanged(); break;
        case 2: _t->itemsChanged(); break;
        case 3: _t->urlsChanged(); break;
        case 4: _t->cachePagesChanged(); break;
        case 5: { QQuickItem* _r = _t->loadPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 6: { QQuickItem* _r = _t->loadPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 7: { QQuickItem* _r = _t->loadPageWithProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 8: { QQuickItem* _r = _t->loadPageWithProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 9: { QUrl _r = _t->urlForPage((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 10: { QQuickItem* _r = _t->pageForUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->contains((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->deletePage((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 13: { QUrl _r = _t->resolvedUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->isLocalUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PagePool::*)()>(_a, &PagePool::lastLoadedUrlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagePool::*)()>(_a, &PagePool::lastLoadedItemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagePool::*)()>(_a, &PagePool::itemsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagePool::*)()>(_a, &PagePool::urlsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PagePool::*)()>(_a, &PagePool::cachePagesChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QQuickItem*> >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->lastLoadedUrl(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->lastLoadedItem(); break;
        case 2: *reinterpret_cast<QList<QQuickItem*>*>(_v) = _t->items(); break;
        case 3: *reinterpret_cast<QList<QUrl>*>(_v) = _t->urls(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->cachePages(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setCachePages(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PagePool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PagePool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PagePoolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PagePool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void PagePool::lastLoadedUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PagePool::lastLoadedItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PagePool::itemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PagePool::urlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PagePool::cachePagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
