/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<alignedsizeattached.h>)
#  include <alignedsizeattached.h>
#endif
#if __has_include(<icon.h>)
#  include <icon.h>
#endif
#if __has_include(<mnemonicattached.h>)
#  include <mnemonicattached.h>
#endif
#if __has_include(<scenepositionattached.h>)
#  include <scenepositionattached.h>
#endif
#if __has_include(<shadowedrectangle.h>)
#  include <shadowedrectangle.h>
#endif
#if __has_include(<shadowedtexture.h>)
#  include <shadowedtexture.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami_primitives()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AlignedSizeAttached>("org.kde.kirigami.primitives", 2);
    qmlRegisterTypesAndRevisions<BorderGroup>("org.kde.kirigami.primitives", 2);
    qmlRegisterTypesAndRevisions<CornersGroup>("org.kde.kirigami.primitives", 2);
    qmlRegisterTypesAndRevisions<Icon>("org.kde.kirigami.primitives", 2);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.kirigami.primitives", 2);
    qmlRegisterEnum<Icon::Status>("Icon::Status");
    qmlRegisterTypesAndRevisions<MnemonicAttached>("org.kde.kirigami.primitives", 2);
    qmlRegisterEnum<MnemonicAttached::ControlType>("MnemonicAttached::ControlType");
    qmlRegisterTypesAndRevisions<ScenePositionAttached>("org.kde.kirigami.primitives", 2);
    qmlRegisterTypesAndRevisions<ShadowGroup>("org.kde.kirigami.primitives", 2);
    qmlRegisterTypesAndRevisions<ShadowedRectangle>("org.kde.kirigami.primitives", 2);
    qmlRegisterEnum<ShadowedRectangle::RenderType>("ShadowedRectangle::RenderType");
    qmlRegisterTypesAndRevisions<ShadowedTexture>("org.kde.kirigami.primitives", 2);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami.primitives", 2, 0);
}

static const QQmlModuleRegistration orgkdekirigamiprimitivesRegistration("org.kde.kirigami.primitives", qml_register_types_org_kde_kirigami_primitives);
